@@ -12,7 +12,7 @@ use Aspect::Hook          ();
 use Aspect::Advice        ();
 use Aspect::Point::Around ();
 
-our $VERSION = '0.45';
+our $VERSION = '0.90';
 our @ISA     = 'Aspect::Advice';
 
 sub _install {
@@ -26,7 +26,8 @@ sub _install {
 	# Because $MATCH_RUN is used in boolean conditionals, if there
 	# is nothing to do the compiler will optimise away the code entirely.
 	my $curried   = $pointcut->match_curry;
-	my $MATCH_RUN = $curried ? '$curried->match_run($runtime)' : 1;
+	my $compiled  = $curried ? $curried->compiled_runtime : undef;
+	my $MATCH_RUN = $compiled ? '$compiled->()' : 1;
 
 	# When an aspect falls out of scope, we don't attempt to remove
 	# the generated hook code, because it might (for reasons potentially
@@ -67,47 +68,42 @@ sub _install {
 
 			# Apply any runtime-specific context checks
 			my \$wantarray = wantarray;
-			my \$runtime   = {
+			local \$_ = bless {
 				type      => 'around',
 				sub_name  => \$name,
 				wantarray => \$wantarray,
 				params    => \\\@_,
-			};
-			goto &\$original unless $MATCH_RUN;
-
-			# Prepare the context object
-			my \$context = bless {
 				return_value => \$wantarray ? [ ] : undef,
 				exception    => undef,
 				pointcut     => \$pointcut,
 				original     => \$original,
-				\%\$runtime,
 			}, 'Aspect::Point::Around';
+			goto &\$original unless $MATCH_RUN;
 
 			# Array context needs some special return handling
 			if ( \$wantarray ) {
 				# Run the advice code
 				() = Sub::Uplevel::uplevel(
-					1, \$code, \$context,
+					1, \$code, \$_,
 				);
 
 				# Don't run the original
-				return \@{\$context->{return_value}};
+				return \@{\$_->{return_value}};
 			}
 
 			# Scalar and void have the same return handling.
 			# Just run the advice code differently.
 			if ( defined \$wantarray ) {
 				my \$dummy = Sub::Uplevel::uplevel(
-					1, \$code, \$context,
+					1, \$code, \$_,
 				);
 			} else {
 				Sub::Uplevel::uplevel(
-					1, \$code, \$context,
+					1, \$code, \$_,
 				);
 			}
 
-			return \$context->{return_value};
+			return \$_->{return_value};
 		};
 END_PERL
 	}
