@@ -5,7 +5,7 @@ use warnings;
 use Aspect::Pointcut        ();
 use Aspect::Pointcut::Logic ();
 
-our $VERSION = '0.45';
+our $VERSION = '0.90';
 our @ISA     = qw{
 	Aspect::Pointcut::Logic
 	Aspect::Pointcut
@@ -18,12 +18,88 @@ our @ISA     = qw{
 ######################################################################
 # Weaving Methods
 
-sub match_define {
-	my $self = shift;
-	foreach ( @$self ) {
-		return 1 if $_->match_define(@_);
+sub compile_weave {
+	my $self     = shift;
+	my @children = map { $_->compile_weave } @$self;
+
+	# Collapse string conditions together,
+	# and further collapse code conditions together.
+	my @string = ();
+	my @code   = ();
+	foreach my $child ( @children ) {
+		# Short-cut if we contain any purely runtime pointcuts
+		unless ( ref $child ) {
+			return 1 if $child eq 1;
+			push @string, $child;
+			next;
+		}
+		if ( @string ) {
+			my $group = join ' or ', map { "( $_ )" } @string;
+			push @code, eval "sub () { $group }";
+			@string = ();
+		}
+		push @code, $child;
 	}
-	return;
+
+	if ( @string ) {
+		my $group = join ' or ', map { "( $_ )" } @string;
+		unless ( @code ) {
+			# This is the only thing we have
+			return $group;
+		}
+		push @code, eval "sub () { $group }";
+	}
+
+	# Join the groups
+	return sub {
+		foreach my $child ( @code ) {
+			return 0 unless $child->();
+		}
+		return 1;
+	};
+
+}
+
+sub compile_runtime {
+	my $self     = shift;
+	my @children = map { $_->compile_runtime } @$self;
+
+	# Collapse string conditions together,
+	# and further collapse code conditions together.
+	my @string = ();
+	my @code   = ();
+	foreach my $child ( @children ) {
+		# Short-cut if we contain any purely runtime pointcuts
+		unless ( ref $child ) {
+			return 1 if $child eq 1;
+			push @string, $child;
+			next;
+		}
+		if ( @string ) {
+			my $group = join ' or ', map { "( $_ )" } @string;
+			push @code, eval "sub () { $group }";
+			@string = ();
+		}
+		push @code, $child;
+	}
+
+	if ( @string ) {
+		my $group = join ' or ', map { "( $_ )" } @string;
+		unless ( @code ) {
+			# This is the only thing we have
+			return $group;
+		}
+		push @code, eval "sub () { $group }";
+	}
+
+	# Join the groups
+	return sub {
+		foreach my $child ( @code ) {
+			return 0 unless $child->();
+		}
+		return 1;
+	};
+
 }
 
 sub match_contains {
@@ -91,21 +167,6 @@ sub match_curry {
 	return ref($self)->new( @list );
 }
 
-
-
-
-
-######################################################################
-# Runtime Methods
-
-sub match_run {
-	my $self = shift;
-	foreach ( @$self ) {
-		return 1 if $_->match_run(@_);
-	}
-	return;
-}
-
 1;
 
 __END__
